import type { BeginUploadRequestDto } from "../models/BeginUploadRequestDto";
import type { BeginUploadResponseDto } from "../models/BeginUploadResponseDto";
import type { CompleteUploadPartRequestDto } from "../models/CompleteUploadPartRequestDto";
import type { FileIdUnboxed } from "../models/FileIdUnboxed";
import type { UploadPartDto } from "../models/UploadPartDto";
import type { UploadPartIndexUnboxed } from "../models/UploadPartIndexUnboxed";
import type { UploadPartListDto } from "../models/UploadPartListDto";
export declare class FilesService {
    /**
     * Begin a file upload.
     * @param requestBody File upload parameters.
     * @returns BeginUploadResponseDto Success.
     * @throws ApiError
     */
    static beginUpload(requestBody: BeginUploadRequestDto): Promise<BeginUploadResponseDto>;
    /**
     * Gets a remaining upload part for an in-progress upload.
     * @param fileId
     * @param uploadPartIndex
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static completeUploadPart(fileId: FileIdUnboxed, uploadPartIndex: UploadPartIndexUnboxed, requestBody: CompleteUploadPartRequestDto): Promise<any>;
    /**
     * Gets a remaining upload part for an in-progress upload.
     * @param fileId
     * @param uploadPartIndex
     * @returns UploadPartDto Success.
     * @throws ApiError
     */
    static getUploadPart(fileId: FileIdUnboxed, uploadPartIndex: UploadPartIndexUnboxed): Promise<UploadPartDto>;
    /**
     * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete.
     * @param fileId
     * @returns UploadPartListDto Success.
     * @throws ApiError
     */
    static getUploadParts(fileId: FileIdUnboxed): Promise<UploadPartListDto>;
}
